------------------------------------------------------------------------------------------
-- LoadAndSave file
-- Written by Homeopatix
-- 26 january 2021
------------------------------------------------------------------------------------------
------------------------------------------------------------------------------------------
-- create or load the settings
------------------------------------------------------------------------------------------
function LoadSettings()
	local _settings = PatchDataLoad(Turbine.DataScope.Account, "AltHolic_Settings", settings);
    if (_settings ~= nil) then 
		settings = _settings; 
	end
------------------------------------------------------------------------------------------
--- adding new vars in the settings file ---
------------------------------------------------------------------------------------------
    if ( not settings.isShowVaultVisible or
    not settings.verbose or
    not settings["sessionCash"]["cashSession"] or
    not settings.isShowSharedStorageVisible or
    not settings.isSearchWindowVisible or
    not settings.isShowEquipmentVisible or
    not settings.isShowEquipmentVisible or
    not settings.displaySpentCash) then		
		settings = {
            windowPosition = { 
                xPos = settings["windowPosition"]["xPos"], 
                yPos = settings["windowPosition"]["yPos"] 
            },
            IconPosition = { 
                xPosIcon = settings["IconPosition"]["xPosIcon"], 
                yPosIcon = settings["IconPosition"]["yPosIcon"] 
            },
            isMinimizeEnabled = { 
                isMinimizeEnabled = settings["isMinimizeEnabled"]["isMinimizeEnabled"] 
            },
            isWindowVisible = { 
                isWindowVisible = settings["isWindowVisible"]["isWindowVisible"] 
            },
            isShowBagVisible = { 
                isShowBagVisible = false   
            },
            isShowVaultVisible = { 
                isShowVaultVisible = false   
            },
            isShowSharedStorageVisible = { 
                isShowSharedStorageVisible = false   
            },
            isOptionsWindowVisible = { 
                isOptionsWindowVisible = false 
            },
            isSearchWindowVisible = { 
                isSearchWindowVisible = false 
            },
            isShowEquipmentVisible = { 
                isShowEquipmentVisible = false   
            },
            displaySpentCash = { 
                value = false 
            },
            verbose = { 
                value = settings["verbose"]["value"] 
            },
            escEnable = { 
                escEnable = settings["escEnable"]["escEnable"] 
            },
            sessionCash = { 
                cashStart = 0,
                cashSession = 0,
                cashSpent = 0
            },
            nameAccount = { 
                account1 = { name = settings["nameAccount"]["account1"]["name"], 
                             nbrAlt = settings["nameAccount"]["account1"]["nbrAlt"], 
                             isVisible = settings["nameAccount"]["account1"]["isVisible"]}
            }
        };
	end
end
------------------------------------------------------------------------------------------
-- create the save settings
------------------------------------------------------------------------------------------
function SaveSettings()
	settings["windowPosition"]["xPos"] = tostring(AltHolicWindow:GetLeft());
    settings["windowPosition"]["yPos"] = tostring(AltHolicWindow:GetTop());
    settings["IconPosition"]["xPosIcon"] = tostring(MainMinimizedIcon:GetLeft());
   	settings["IconPosition"]["yPosIcon"] = tostring(MainMinimizedIcon:GetTop());
	settings["isMinimizeEnabled"]["isMinimizeEnabled"] = settings["isMinimizeEnabled"]["isMinimizeEnabled"];
	settings["isWindowVisible"]["isWindowVisible"] = settings["isWindowVisible"]["isWindowVisible"];
    settings["isShowBagVisible"]["isShowBagVisible"] = settings["isShowBagVisible"]["isShowBagVisible"];
    settings["isShowSharedStorageVisible"]["isShowSharedStorageVisible"] = settings["isShowSharedStorageVisible"]["isShowSharedStorageVisible"];
    settings["isSearchWindowVisible"]["isSearchWindowVisible"] = settings["isSearchWindowVisible"]["isSearchWindowVisible"];

    settings["isShowVaultVisible"]["isShowVaultVisible"] = settings["isShowVaultVisible"]["isShowVaultVisible"];
    settings["isOptionsWindowVisible"]["isOptionsWindowVisible"] = settings["isOptionsWindowVisible"]["isOptionsWindowVisible"];
	settings["escEnable"]["escEnable"] = settings["escEnable"]["escEnable"];
    -- save the settings
    settings["nameAccount"]["account1"] = settings["nameAccount"]["account1"];
    settings["sessionCash"]["cashStart"] = settings["sessionCash"]["cashStart"];
    settings["verbose"]["value"] = settings["verbose"]["value"];
    settings["displaySpentCash"]["value"] = settings["displaySpentCash"]["value"];

	PatchDataSave( Turbine.DataScope.Account, "AltHolic_Settings", settings);
end
------------------------------------------------------------------------------------------
-- create or load the settings for player datas
------------------------------------------------------------------------------------------
function LoadPlayerDatas()
    PlayerDatas = PatchDataLoad(Turbine.DataScope.Account, "AltHolic_PlayerDatas", PlayerDatas);

    if (PlayerDatas == nil)then 
        PlayerDatas = {}; 
    end

    if (PlayerDatas[PlayerName] == nil)then 
        PlayerDatas[PlayerName] = {}; 
    end
end
------------------------------------------------------------------------------------------
-- create the save settings for player datas
------------------------------------------------------------------------------------------
function SavePlayerDatas()
    if ( string.sub( PlayerName, 1, 1 ) == "~" )then return end; --Ignore session play

    PlayerDatas[PlayerName] = {};

    PlayerDatas[PlayerName].cla = PlayerClass;
    PlayerDatas[PlayerName].lvl = PlayerLvl;
    PlayerDatas[PlayerName].voc = PlayerVoc;
    PlayerDatas[PlayerName].rac = PlayerRace;
    PlayerDatas[PlayerName].cash = PlayerCash;
    PlayerDatas[PlayerName].align = PlayerAlignement

    PatchDataSave( Turbine.DataScope.Account, "AltHolic_PlayerDatas", PlayerDatas);
end
------------------------------------------------------------------------------------------
-- create or load the settings for player bag
------------------------------------------------------------------------------------------
function LoadPlayerBags()
    PlayerBags = PatchDataLoad(Turbine.DataScope.Account, "AltHolic_Bags", PlayerBags);
    if (PlayerBags == nil)then 
        PlayerBags = {}; 
    end
    if (PlayerBags[PlayerName] == nil)then 
        PlayerBags[PlayerName] = {}; 
    end
end
------------------------------------------------------------------------------------------
-- create the save settingsfor player bag
------------------------------------------------------------------------------------------
function SavePlayerBags()
    if ( string.sub( PlayerName, 1, 1 ) == "~" )then return end; --Ignore session play

    backpackSize = backpack:GetSize();

    PlayerBags[PlayerName] = {};

    slot = 1;
    for i = 1, backpackSize do

        local items = backpack:GetItem( i );
        if (items ~= nil) then
            local ind = tostring(slot);
            PlayerBags[PlayerName][ind] = items;
            local iteminfo = PlayerBags[PlayerName][ind]:GetItemInfo();

            PlayerBags[PlayerName][ind].Q = tostring(iteminfo:GetQualityImageID());
            PlayerBags[PlayerName][ind].B = tostring(iteminfo:GetBackgroundImageID());
            PlayerBags[PlayerName][ind].U = tostring(iteminfo:GetUnderlayImageID());
            PlayerBags[PlayerName][ind].S = tostring(iteminfo:GetShadowImageID());
            PlayerBags[PlayerName][ind].I = tostring(iteminfo:GetIconImageID());
            PlayerBags[PlayerName][ind].N = tostring(iteminfo:GetName());

            local tq = tostring(PlayerBags[PlayerName][ind]:GetQuantity());

           -- if (tq == "1")then 
            --    tq = ""; 
           -- end

            PlayerBags[PlayerName][ind].QUA = tq;
            PlayerBags[PlayerName][ind].BSIZE = tostring(backpackSize);

            slot = slot +  1;
        end
    end
    settings["nameAccount"]["account1"]["isVisible"] = false;
    PatchDataSave( Turbine.DataScope.Account, "AltHolic_Bags", PlayerBags);
end
------------------------------------------------------------------------------------------
-- create or load the settings for vault
------------------------------------------------------------------------------------------
function LoadPlayerVault()
    PlayerVault = PatchDataLoad(Turbine.DataScope.Account, "AltHolic_Vaults", PlayerVault);
    if (PlayerVault == nil)then 
        PlayerVault = {}; 
    end
    if (PlayerVault[PlayerName] == nil)then 
        PlayerVault[PlayerName] = {}; 
    end
end
------------------------------------------------------------------------------------------
-- create the save settings for vault
------------------------------------------------------------------------------------------
function SavePlayerVault()
    if ( string.sub( PlayerName, 1, 1 ) == "~" )then return end; --Ignore session play

    vaultpackSize = vaultpack:GetCapacity();
    vaultpackCount = vaultpack:GetCount();

    PlayerVault[PlayerName] = {};

    for slot = 1, vaultpackCount do
        local ind = tostring(slot);
        PlayerVault[PlayerName][ind] = vaultpack:GetItem(slot);
        local iteminfo = PlayerVault[PlayerName][ind]:GetItemInfo();

        PlayerVault[PlayerName][ind].Q = tostring(iteminfo:GetQualityImageID());
        PlayerVault[PlayerName][ind].B = tostring(iteminfo:GetBackgroundImageID());
        PlayerVault[PlayerName][ind].U = tostring(iteminfo:GetUnderlayImageID());
        PlayerVault[PlayerName][ind].S = tostring(iteminfo:GetShadowImageID());
        PlayerVault[PlayerName][ind].I = tostring(iteminfo:GetIconImageID());
        PlayerVault[PlayerName][ind].N = tostring(iteminfo:GetName());

        local tq = tostring(PlayerVault[PlayerName][ind]:GetQuantity());
        --if (tq == "1" )then 
         --   tq = ""; 
       -- end

        PlayerVault[PlayerName][ind].QUA = tq;
        PlayerVault[PlayerName][ind].VSIZE = tostring(vaultpackSize);
    end

    PatchDataSave( Turbine.DataScope.Account, "AltHolic_Vaults", PlayerVault);
end
------------------------------------------------------------------------------------------
-- create or load the settings for equipment
------------------------------------------------------------------------------------------
function LoadPlayerEquipment()
    PlayerEquipement = PatchDataLoad(Turbine.DataScope.Account, "AltHolic_PlayerEquipement", PlayerEquipement);

    if (PlayerEquipement == nil)then 
        PlayerEquipement = {}; 
    end
    if (PlayerEquipement[PlayerName] == nil)then 
        PlayerEquipement[PlayerName] = {};         
    end

    if (PlayerEquipement[PlayerName].Back == nil)then 
        PlayerEquipement[PlayerName].Back = {};         
    end
    if (PlayerEquipement[PlayerName].Boots == nil)then 
        PlayerEquipement[PlayerName].Boots = {};         
    end
    if (PlayerEquipement[PlayerName].Bracelet1 == nil)then 
        PlayerEquipement[PlayerName].Bracelet1 = {};         
    end
    if (PlayerEquipement[PlayerName].Bracelet2 == nil)then 
        PlayerEquipement[PlayerName].Bracelet2 = {};         
    end
    if (PlayerEquipement[PlayerName].Chest == nil)then 
        PlayerEquipement[PlayerName].Chest = {};         
    end
    if (PlayerEquipement[PlayerName].ClassE == nil)then 
        PlayerEquipement[PlayerName].ClassE = {};         
    end
    if (PlayerEquipement[PlayerName].CraftTool == nil)then 
        PlayerEquipement[PlayerName].CraftTool = {};         
    end
    if (PlayerEquipement[PlayerName].Earring1 == nil)then 
        PlayerEquipement[PlayerName].Earring1 = {};         
    end
    if (PlayerEquipement[PlayerName].Earring2 == nil)then 
        PlayerEquipement[PlayerName].Earring2 = {};         
    end
    if (PlayerEquipement[PlayerName].Gloves == nil)then 
        PlayerEquipement[PlayerName].Gloves = {};         
    end
    if (PlayerEquipement[PlayerName].Head == nil)then 
        PlayerEquipement[PlayerName].Head = {};         
    end
    if (PlayerEquipement[PlayerName].Legs == nil)then 
        PlayerEquipement[PlayerName].Legs = {};         
    end
    if (PlayerEquipement[PlayerName].Necklace == nil)then 
        PlayerEquipement[PlayerName].Necklace = {};         
    end
    if (PlayerEquipement[PlayerName].Pocket == nil)then 
        PlayerEquipement[PlayerName].Pocket = {};         
    end
    if (PlayerEquipement[PlayerName].PrimaryWeapon == nil)then 
        PlayerEquipement[PlayerName].PrimaryWeapon = {};         
    end
    if (PlayerEquipement[PlayerName].RangedWeapon == nil)then 
        PlayerEquipement[PlayerName].RangedWeapon = {};         
    end
    if (PlayerEquipement[PlayerName].Ring1 == nil)then 
        PlayerEquipement[PlayerName].Ring1 = {};         
    end
    if (PlayerEquipement[PlayerName].Ring2 == nil)then 
        PlayerEquipement[PlayerName].Ring2 = {};         
    end
    if (PlayerEquipement[PlayerName].Shield == nil)then 
        PlayerEquipement[PlayerName].Shield = {};         
    end
    if (PlayerEquipement[PlayerName].Shoulder == nil)then 
        PlayerEquipement[PlayerName].Shoulder = {};         
    end
end
------------------------------------------------------------------------------------------
-- create the save settings for equipment
------------------------------------------------------------------------------------------
function SavePlayerEquipment()
    if ( string.sub( PlayerName, 1, 1 ) == "~" )then return end; --Ignore session play

    PlayerEquipement[PlayerName].Back = {};
    PlayerEquipement[PlayerName].Boots = {};
    PlayerEquipement[PlayerName].Bracelet1 = {};
    PlayerEquipement[PlayerName].Bracelet2 = {};
    PlayerEquipement[PlayerName].Chest = {};
    PlayerEquipement[PlayerName].ClassE = {};
    PlayerEquipement[PlayerName].CraftTool = {};
    PlayerEquipement[PlayerName].Earring1 = {};
    PlayerEquipement[PlayerName].Earring2 = {};
    PlayerEquipement[PlayerName].Gloves = {};
    PlayerEquipement[PlayerName].Head = {};
    PlayerEquipement[PlayerName].Legs = {};
    PlayerEquipement[PlayerName].Necklace = {};
    PlayerEquipement[PlayerName].Pocket = {};
    PlayerEquipement[PlayerName].PrimaryWeapon = {};
    PlayerEquipement[PlayerName].RangedWeapon = {};
    PlayerEquipement[PlayerName].Ring1 = {};
    PlayerEquipement[PlayerName].Ring2 = {};
    PlayerEquipement[PlayerName].Shield = {};
    PlayerEquipement[PlayerName].Shoulder = {};

    if(PlayerEquip:GetItem(1) ~= nil)then
    PlayerEquipement[PlayerName].Head.Q = PlayerEquip:GetItem(1):GetItemInfo():GetQualityImageID();
    PlayerEquipement[PlayerName].Head.B = PlayerEquip:GetItem(1):GetItemInfo():GetBackgroundImageID();
    PlayerEquipement[PlayerName].Head.U = PlayerEquip:GetItem(1):GetItemInfo():GetUnderlayImageID();
    PlayerEquipement[PlayerName].Head.S = PlayerEquip:GetItem(1):GetItemInfo():GetShadowImageID();
    PlayerEquipement[PlayerName].Head.I = PlayerEquip:GetItem(1):GetItemInfo():GetIconImageID();
    PlayerEquipement[PlayerName].Head.N = PlayerEquip:GetItem(1):GetItemInfo():GetName();
    PlayerEquipement[PlayerName].Head.QA = PlayerEquip:GetItem(1):GetItemInfo():GetQuality();
    PlayerEquipement[PlayerName].Head.CAT = PlayerEquip:GetItem(1):GetItemInfo():GetCategory();
    end
    if(PlayerEquip:GetItem(2) ~= nil)then
    PlayerEquipement[PlayerName].Chest.Q = PlayerEquip:GetItem(2):GetItemInfo():GetQualityImageID();
    PlayerEquipement[PlayerName].Chest.B = PlayerEquip:GetItem(2):GetItemInfo():GetBackgroundImageID();
    PlayerEquipement[PlayerName].Chest.U = PlayerEquip:GetItem(2):GetItemInfo():GetUnderlayImageID();
    PlayerEquipement[PlayerName].Chest.S = PlayerEquip:GetItem(2):GetItemInfo():GetShadowImageID();
    PlayerEquipement[PlayerName].Chest.I = PlayerEquip:GetItem(2):GetItemInfo():GetIconImageID();
    PlayerEquipement[PlayerName].Chest.N = PlayerEquip:GetItem(2):GetItemInfo():GetName();
    PlayerEquipement[PlayerName].Chest.QA = PlayerEquip:GetItem(2):GetItemInfo():GetQuality();
    PlayerEquipement[PlayerName].Chest.CAT = PlayerEquip:GetItem(2):GetItemInfo():GetCategory();
    end
    if(PlayerEquip:GetItem(3) ~= nil)then
    PlayerEquipement[PlayerName].Legs.Q = PlayerEquip:GetItem(3):GetItemInfo():GetQualityImageID();
    PlayerEquipement[PlayerName].Legs.B = PlayerEquip:GetItem(3):GetItemInfo():GetBackgroundImageID();
    PlayerEquipement[PlayerName].Legs.U = PlayerEquip:GetItem(3):GetItemInfo():GetUnderlayImageID();
    PlayerEquipement[PlayerName].Legs.S = PlayerEquip:GetItem(3):GetItemInfo():GetShadowImageID();
    PlayerEquipement[PlayerName].Legs.I = PlayerEquip:GetItem(3):GetItemInfo():GetIconImageID();
    PlayerEquipement[PlayerName].Legs.N = PlayerEquip:GetItem(3):GetItemInfo():GetName();
    PlayerEquipement[PlayerName].Legs.QA = PlayerEquip:GetItem(3):GetItemInfo():GetQuality();
    PlayerEquipement[PlayerName].Legs.CAT = PlayerEquip:GetItem(3):GetItemInfo():GetCategory();
    end
    if(PlayerEquip:GetItem(4) ~= nil)then
    PlayerEquipement[PlayerName].Gloves.Q = PlayerEquip:GetItem(4):GetItemInfo():GetQualityImageID();
    PlayerEquipement[PlayerName].Gloves.B = PlayerEquip:GetItem(4):GetItemInfo():GetBackgroundImageID();
    PlayerEquipement[PlayerName].Gloves.U = PlayerEquip:GetItem(4):GetItemInfo():GetUnderlayImageID();
    PlayerEquipement[PlayerName].Gloves.S = PlayerEquip:GetItem(4):GetItemInfo():GetShadowImageID();
    PlayerEquipement[PlayerName].Gloves.I = PlayerEquip:GetItem(4):GetItemInfo():GetIconImageID();
    PlayerEquipement[PlayerName].Gloves.N = PlayerEquip:GetItem(4):GetItemInfo():GetName();
    PlayerEquipement[PlayerName].Gloves.QA = PlayerEquip:GetItem(4):GetItemInfo():GetQuality();
    PlayerEquipement[PlayerName].Gloves.CAT = PlayerEquip:GetItem(4):GetItemInfo():GetCategory();
    end
    if(PlayerEquip:GetItem(5) ~= nil)then
    PlayerEquipement[PlayerName].Boots.Q = PlayerEquip:GetItem(5):GetItemInfo():GetQualityImageID();
    PlayerEquipement[PlayerName].Boots.B = PlayerEquip:GetItem(5):GetItemInfo():GetBackgroundImageID();
    PlayerEquipement[PlayerName].Boots.U = PlayerEquip:GetItem(5):GetItemInfo():GetUnderlayImageID();
    PlayerEquipement[PlayerName].Boots.S = PlayerEquip:GetItem(5):GetItemInfo():GetShadowImageID();
    PlayerEquipement[PlayerName].Boots.I = PlayerEquip:GetItem(5):GetItemInfo():GetIconImageID();
    PlayerEquipement[PlayerName].Boots.N = PlayerEquip:GetItem(5):GetItemInfo():GetName();
    PlayerEquipement[PlayerName].Boots.QA = PlayerEquip:GetItem(5):GetItemInfo():GetQuality();
    PlayerEquipement[PlayerName].Boots.CAT = PlayerEquip:GetItem(5):GetItemInfo():GetCategory();
    end
    if(PlayerEquip:GetItem(6) ~= nil)then
    PlayerEquipement[PlayerName].Shoulder.Q = PlayerEquip:GetItem(6):GetItemInfo():GetQualityImageID();
    PlayerEquipement[PlayerName].Shoulder.B = PlayerEquip:GetItem(6):GetItemInfo():GetBackgroundImageID();
    PlayerEquipement[PlayerName].Shoulder.U = PlayerEquip:GetItem(6):GetItemInfo():GetUnderlayImageID();
    PlayerEquipement[PlayerName].Shoulder.S = PlayerEquip:GetItem(6):GetItemInfo():GetShadowImageID();
    PlayerEquipement[PlayerName].Shoulder.I = PlayerEquip:GetItem(6):GetItemInfo():GetIconImageID();
    PlayerEquipement[PlayerName].Shoulder.N = PlayerEquip:GetItem(6):GetItemInfo():GetName();
    PlayerEquipement[PlayerName].Shoulder.QA = PlayerEquip:GetItem(6):GetItemInfo():GetQuality();
    PlayerEquipement[PlayerName].Shoulder.CAT = PlayerEquip:GetItem(6):GetItemInfo():GetCategory();
    end
    if(PlayerEquip:GetItem(7) ~= nil)then
    PlayerEquipement[PlayerName].Back.Q = PlayerEquip:GetItem(7):GetItemInfo():GetQualityImageID();
    PlayerEquipement[PlayerName].Back.B = PlayerEquip:GetItem(7):GetItemInfo():GetBackgroundImageID();
    PlayerEquipement[PlayerName].Back.U = PlayerEquip:GetItem(7):GetItemInfo():GetUnderlayImageID();
    PlayerEquipement[PlayerName].Back.S = PlayerEquip:GetItem(7):GetItemInfo():GetShadowImageID();
    PlayerEquipement[PlayerName].Back.I = PlayerEquip:GetItem(7):GetItemInfo():GetIconImageID();
    PlayerEquipement[PlayerName].Back.N = PlayerEquip:GetItem(7):GetItemInfo():GetName();
    PlayerEquipement[PlayerName].Back.QA = PlayerEquip:GetItem(7):GetItemInfo():GetQuality();
    PlayerEquipement[PlayerName].Back.CAT = PlayerEquip:GetItem(7):GetItemInfo():GetCategory();
    end
    if(PlayerEquip:GetItem(8) ~= nil)then
    PlayerEquipement[PlayerName].Bracelet1.Q = PlayerEquip:GetItem(8):GetItemInfo():GetQualityImageID();
    PlayerEquipement[PlayerName].Bracelet1.B = PlayerEquip:GetItem(8):GetItemInfo():GetBackgroundImageID();
    PlayerEquipement[PlayerName].Bracelet1.U = PlayerEquip:GetItem(8):GetItemInfo():GetUnderlayImageID();
    PlayerEquipement[PlayerName].Bracelet1.S = PlayerEquip:GetItem(8):GetItemInfo():GetShadowImageID();
    PlayerEquipement[PlayerName].Bracelet1.I = PlayerEquip:GetItem(8):GetItemInfo():GetIconImageID();
    PlayerEquipement[PlayerName].Bracelet1.N = PlayerEquip:GetItem(8):GetItemInfo():GetName();
    PlayerEquipement[PlayerName].Bracelet1.QA = PlayerEquip:GetItem(8):GetItemInfo():GetQuality();
    PlayerEquipement[PlayerName].Bracelet1.CAT = PlayerEquip:GetItem(8):GetItemInfo():GetCategory();
    end
    if(PlayerEquip:GetItem(9) ~= nil)then
    PlayerEquipement[PlayerName].Bracelet2.Q = PlayerEquip:GetItem(9):GetItemInfo():GetQualityImageID();
    PlayerEquipement[PlayerName].Bracelet2.B = PlayerEquip:GetItem(9):GetItemInfo():GetBackgroundImageID();
    PlayerEquipement[PlayerName].Bracelet2.U = PlayerEquip:GetItem(9):GetItemInfo():GetUnderlayImageID();
    PlayerEquipement[PlayerName].Bracelet2.S = PlayerEquip:GetItem(9):GetItemInfo():GetShadowImageID();
    PlayerEquipement[PlayerName].Bracelet2.I = PlayerEquip:GetItem(9):GetItemInfo():GetIconImageID();
    PlayerEquipement[PlayerName].Bracelet2.N = PlayerEquip:GetItem(9):GetItemInfo():GetName();
    PlayerEquipement[PlayerName].Bracelet2.QA = PlayerEquip:GetItem(9):GetItemInfo():GetQuality();
    PlayerEquipement[PlayerName].Bracelet2.CAT = PlayerEquip:GetItem(9):GetItemInfo():GetCategory();
    end
    if(PlayerEquip:GetItem(10) ~= nil)then
    PlayerEquipement[PlayerName].Necklace.Q = PlayerEquip:GetItem(10):GetItemInfo():GetQualityImageID();
    PlayerEquipement[PlayerName].Necklace.B = PlayerEquip:GetItem(10):GetItemInfo():GetBackgroundImageID();
    PlayerEquipement[PlayerName].Necklace.U = PlayerEquip:GetItem(10):GetItemInfo():GetUnderlayImageID();
    PlayerEquipement[PlayerName].Necklace.S = PlayerEquip:GetItem(10):GetItemInfo():GetShadowImageID();
    PlayerEquipement[PlayerName].Necklace.I = PlayerEquip:GetItem(10):GetItemInfo():GetIconImageID();
    PlayerEquipement[PlayerName].Necklace.N = PlayerEquip:GetItem(10):GetItemInfo():GetName();
    PlayerEquipement[PlayerName].Necklace.QA = PlayerEquip:GetItem(10):GetItemInfo():GetQuality();
    PlayerEquipement[PlayerName].Necklace.CAT = PlayerEquip:GetItem(10):GetItemInfo():GetCategory();
    end
    if(PlayerEquip:GetItem(11) ~= nil)then
    PlayerEquipement[PlayerName].Ring1.Q = PlayerEquip:GetItem(11):GetItemInfo():GetQualityImageID();
    PlayerEquipement[PlayerName].Ring1.B = PlayerEquip:GetItem(11):GetItemInfo():GetBackgroundImageID();
    PlayerEquipement[PlayerName].Ring1.U = PlayerEquip:GetItem(11):GetItemInfo():GetUnderlayImageID();
    PlayerEquipement[PlayerName].Ring1.S = PlayerEquip:GetItem(11):GetItemInfo():GetShadowImageID();
    PlayerEquipement[PlayerName].Ring1.I = PlayerEquip:GetItem(11):GetItemInfo():GetIconImageID();
    PlayerEquipement[PlayerName].Ring1.N = PlayerEquip:GetItem(11):GetItemInfo():GetName();
    PlayerEquipement[PlayerName].Ring1.QA = PlayerEquip:GetItem(11):GetItemInfo():GetQuality();
    PlayerEquipement[PlayerName].Ring1.CAT = PlayerEquip:GetItem(11):GetItemInfo():GetCategory();
    end
    if(PlayerEquip:GetItem(12) ~= nil)then
    PlayerEquipement[PlayerName].Ring2.Q = PlayerEquip:GetItem(12):GetItemInfo():GetQualityImageID();
    PlayerEquipement[PlayerName].Ring2.B = PlayerEquip:GetItem(12):GetItemInfo():GetBackgroundImageID();
    PlayerEquipement[PlayerName].Ring2.U = PlayerEquip:GetItem(12):GetItemInfo():GetUnderlayImageID();
    PlayerEquipement[PlayerName].Ring2.S = PlayerEquip:GetItem(12):GetItemInfo():GetShadowImageID();
    PlayerEquipement[PlayerName].Ring2.I = PlayerEquip:GetItem(12):GetItemInfo():GetIconImageID();
    PlayerEquipement[PlayerName].Ring2.N = PlayerEquip:GetItem(12):GetItemInfo():GetName();
    PlayerEquipement[PlayerName].Ring2.QA = PlayerEquip:GetItem(12):GetItemInfo():GetQuality();
    PlayerEquipement[PlayerName].Ring2.CAT = PlayerEquip:GetItem(12):GetItemInfo():GetCategory();
    end
    if(PlayerEquip:GetItem(13) ~= nil)then
    PlayerEquipement[PlayerName].Earring1.Q = PlayerEquip:GetItem(13):GetItemInfo():GetQualityImageID();
    PlayerEquipement[PlayerName].Earring1.B = PlayerEquip:GetItem(13):GetItemInfo():GetBackgroundImageID();
    PlayerEquipement[PlayerName].Earring1.U = PlayerEquip:GetItem(13):GetItemInfo():GetUnderlayImageID();
    PlayerEquipement[PlayerName].Earring1.S = PlayerEquip:GetItem(13):GetItemInfo():GetShadowImageID();
    PlayerEquipement[PlayerName].Earring1.I = PlayerEquip:GetItem(13):GetItemInfo():GetIconImageID();
    PlayerEquipement[PlayerName].Earring1.N = PlayerEquip:GetItem(13):GetItemInfo():GetName();
    PlayerEquipement[PlayerName].Earring1.QA = PlayerEquip:GetItem(13):GetItemInfo():GetQuality();
    PlayerEquipement[PlayerName].Earring1.CAT = PlayerEquip:GetItem(13):GetItemInfo():GetCategory();
    end
    if(PlayerEquip:GetItem(14) ~= nil)then
    PlayerEquipement[PlayerName].Earring2.Q = PlayerEquip:GetItem(14):GetItemInfo():GetQualityImageID();
    PlayerEquipement[PlayerName].Earring2.B = PlayerEquip:GetItem(14):GetItemInfo():GetBackgroundImageID();
    PlayerEquipement[PlayerName].Earring2.U = PlayerEquip:GetItem(14):GetItemInfo():GetUnderlayImageID();
    PlayerEquipement[PlayerName].Earring2.S = PlayerEquip:GetItem(14):GetItemInfo():GetShadowImageID();
    PlayerEquipement[PlayerName].Earring2.I = PlayerEquip:GetItem(14):GetItemInfo():GetIconImageID();
    PlayerEquipement[PlayerName].Earring2.N = PlayerEquip:GetItem(14):GetItemInfo():GetName();
    PlayerEquipement[PlayerName].Earring2.QA = PlayerEquip:GetItem(14):GetItemInfo():GetQuality();
    PlayerEquipement[PlayerName].Earring2.CAT = PlayerEquip:GetItem(14):GetItemInfo():GetCategory();
    end
    if(PlayerEquip:GetItem(15) ~= nil)then
    PlayerEquipement[PlayerName].Pocket.Q = PlayerEquip:GetItem(15):GetItemInfo():GetQualityImageID();
    PlayerEquipement[PlayerName].Pocket.B = PlayerEquip:GetItem(15):GetItemInfo():GetBackgroundImageID();
    PlayerEquipement[PlayerName].Pocket.U = PlayerEquip:GetItem(15):GetItemInfo():GetUnderlayImageID();
    PlayerEquipement[PlayerName].Pocket.S = PlayerEquip:GetItem(15):GetItemInfo():GetShadowImageID();
    PlayerEquipement[PlayerName].Pocket.I = PlayerEquip:GetItem(15):GetItemInfo():GetIconImageID();
    PlayerEquipement[PlayerName].Pocket.N = PlayerEquip:GetItem(15):GetItemInfo():GetName();
    PlayerEquipement[PlayerName].Pocket.QA = PlayerEquip:GetItem(15):GetItemInfo():GetQuality();
    PlayerEquipement[PlayerName].Pocket.CAT = PlayerEquip:GetItem(15):GetItemInfo():GetCategory();
    end
    if(PlayerEquip:GetItem(16) ~= nil)then
    PlayerEquipement[PlayerName].PrimaryWeapon.Q = PlayerEquip:GetItem(16):GetItemInfo():GetQualityImageID();
    PlayerEquipement[PlayerName].PrimaryWeapon.B = PlayerEquip:GetItem(16):GetItemInfo():GetBackgroundImageID();
    PlayerEquipement[PlayerName].PrimaryWeapon.U = PlayerEquip:GetItem(16):GetItemInfo():GetUnderlayImageID();
    PlayerEquipement[PlayerName].PrimaryWeapon.S = PlayerEquip:GetItem(16):GetItemInfo():GetShadowImageID();
    PlayerEquipement[PlayerName].PrimaryWeapon.I = PlayerEquip:GetItem(16):GetItemInfo():GetIconImageID();
    PlayerEquipement[PlayerName].PrimaryWeapon.N = PlayerEquip:GetItem(16):GetItemInfo():GetName();
    PlayerEquipement[PlayerName].PrimaryWeapon.QA = PlayerEquip:GetItem(16):GetItemInfo():GetQuality();
    PlayerEquipement[PlayerName].PrimaryWeapon.CAT = PlayerEquip:GetItem(16):GetItemInfo():GetCategory();
    end
    if(PlayerEquip:GetItem(17) ~= nil)then
    PlayerEquipement[PlayerName].Shield.Q = PlayerEquip:GetItem(17):GetItemInfo():GetQualityImageID();
    PlayerEquipement[PlayerName].Shield.B = PlayerEquip:GetItem(17):GetItemInfo():GetBackgroundImageID();
    PlayerEquipement[PlayerName].Shield.U = PlayerEquip:GetItem(17):GetItemInfo():GetUnderlayImageID();
    PlayerEquipement[PlayerName].Shield.S = PlayerEquip:GetItem(17):GetItemInfo():GetShadowImageID();
    PlayerEquipement[PlayerName].Shield.I = PlayerEquip:GetItem(17):GetItemInfo():GetIconImageID();
    PlayerEquipement[PlayerName].Shield.N = PlayerEquip:GetItem(17):GetItemInfo():GetName();
    PlayerEquipement[PlayerName].Shield.QA = PlayerEquip:GetItem(17):GetItemInfo():GetQuality();
    PlayerEquipement[PlayerName].Shield.CAT = PlayerEquip:GetItem(17):GetItemInfo():GetCategory();
    end
    if(PlayerEquip:GetItem(18) ~= nil)then
    PlayerEquipement[PlayerName].RangedWeapon.Q = PlayerEquip:GetItem(18):GetItemInfo():GetQualityImageID();
    PlayerEquipement[PlayerName].RangedWeapon.B = PlayerEquip:GetItem(18):GetItemInfo():GetBackgroundImageID();
    PlayerEquipement[PlayerName].RangedWeapon.U = PlayerEquip:GetItem(18):GetItemInfo():GetUnderlayImageID();
    PlayerEquipement[PlayerName].RangedWeapon.S = PlayerEquip:GetItem(18):GetItemInfo():GetShadowImageID();
    PlayerEquipement[PlayerName].RangedWeapon.I = PlayerEquip:GetItem(18):GetItemInfo():GetIconImageID();
    PlayerEquipement[PlayerName].RangedWeapon.N = PlayerEquip:GetItem(18):GetItemInfo():GetName();
    PlayerEquipement[PlayerName].RangedWeapon.QA = PlayerEquip:GetItem(18):GetItemInfo():GetQuality();
    PlayerEquipement[PlayerName].RangedWeapon.CAT = PlayerEquip:GetItem(18):GetItemInfo():GetCategory();
    end
    if(PlayerEquip:GetItem(19) ~= nil)then
    PlayerEquipement[PlayerName].CraftTool.Q = PlayerEquip:GetItem(19):GetItemInfo():GetQualityImageID();
    PlayerEquipement[PlayerName].CraftTool.B = PlayerEquip:GetItem(19):GetItemInfo():GetBackgroundImageID();
    PlayerEquipement[PlayerName].CraftTool.U = PlayerEquip:GetItem(19):GetItemInfo():GetUnderlayImageID();
    PlayerEquipement[PlayerName].CraftTool.S = PlayerEquip:GetItem(19):GetItemInfo():GetShadowImageID();
    PlayerEquipement[PlayerName].CraftTool.I = PlayerEquip:GetItem(19):GetItemInfo():GetIconImageID();
    PlayerEquipement[PlayerName].CraftTool.N = PlayerEquip:GetItem(19):GetItemInfo():GetName();
    PlayerEquipement[PlayerName].CraftTool.QA = PlayerEquip:GetItem(19):GetItemInfo():GetQuality();
    PlayerEquipement[PlayerName].CraftTool.CAT = PlayerEquip:GetItem(19):GetItemInfo():GetCategory();
    end
    if(PlayerEquip:GetItem(20) ~= nil)then
        PlayerEquipement[PlayerName].ClassE.Q = PlayerEquip:GetItem(20):GetItemInfo():GetQualityImageID();
        PlayerEquipement[PlayerName].ClassE.B = PlayerEquip:GetItem(20):GetItemInfo():GetBackgroundImageID();
        PlayerEquipement[PlayerName].ClassE.U = PlayerEquip:GetItem(20):GetItemInfo():GetUnderlayImageID();
        PlayerEquipement[PlayerName].ClassE.S = PlayerEquip:GetItem(20):GetItemInfo():GetShadowImageID();
        PlayerEquipement[PlayerName].ClassE.I = PlayerEquip:GetItem(20):GetItemInfo():GetIconImageID();
        PlayerEquipement[PlayerName].ClassE.N = PlayerEquip:GetItem(20):GetItemInfo():GetName();
        PlayerEquipement[PlayerName].ClassE.QA = PlayerEquip:GetItem(20):GetItemInfo():GetQuality();
        PlayerEquipement[PlayerName].ClassE.CAT = PlayerEquip:GetItem(20):GetItemInfo():GetCategory();
    end

    PatchDataSave( Turbine.DataScope.Account, "AltHolic_PlayerEquipement", PlayerEquipement);
end
------------------------------------------------------------------------------------------
-- create or load the settings for vault
------------------------------------------------------------------------------------------
function LoadSharedStorage()
    SharedStorageVault = PatchDataLoad(Turbine.DataScope.Account, "AltHolic_SharedStorage", SharedStorageVault);
    if (SharedStorageVault == nil)then 
        SharedStorageVault = {}; 
    end
end
------------------------------------------------------------------------------------------
-- create the save settings for vault
------------------------------------------------------------------------------------------
function SaveSharedStorage()
    if ( string.sub( PlayerName, 1, 1 ) == "~" )then return end; --Ignore session play

    sharedStorageSize = sspack:GetCapacity();
    sharedStorageCount = sspack:GetCount();

    SharedStorageVault = {};

    for slot = 1, sharedStorageCount do
        local ind = tostring(slot);
        SharedStorageVault[ind] = sspack:GetItem(slot);
        local iteminfo = SharedStorageVault[ind]:GetItemInfo();

        SharedStorageVault[ind].Q = tostring(iteminfo:GetQualityImageID());
        SharedStorageVault[ind].B = tostring(iteminfo:GetBackgroundImageID());
        SharedStorageVault[ind].U = tostring(iteminfo:GetUnderlayImageID());
        SharedStorageVault[ind].S = tostring(iteminfo:GetShadowImageID());
        SharedStorageVault[ind].I = tostring(iteminfo:GetIconImageID());
        SharedStorageVault[ind].N = tostring(iteminfo:GetName());

        local tq = tostring(SharedStorageVault[ind]:GetQuantity());
        --if (tq == "1" )then 
           -- tq = ""; 
        --end

        SharedStorageVault[ind].QUA = tq;
        SharedStorageVault[ind].VSIZE = tostring(sharedStorageSize);
    end

    PatchDataSave( Turbine.DataScope.Account, "AltHolic_SharedStorage", SharedStorageVault);
end